<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author DoK <kamberd@yahoo.com>
 * @author Dotan Kamber <kamberd@yahoo.com>
 * @author Moshe Kaplan <mokplan@gmail.com>
 * @author Yaron Yogev <yaronyogev@gmail.com>
 * @author Yaron Shahrabani <sh.yaron@gmail.com>
 */
$lang['menu']                  = 'ניהול הרחבות';
$lang['download']              = 'הורדת והתקנת הרחבה חדשה';
$lang['manage']                = 'הרחבות מותקנות';
$lang['btn_info']              = 'מידע';
$lang['btn_update']            = 'עידכון';
$lang['btn_delete']            = 'מחיקה';
$lang['btn_settings']          = 'הגדרות';
$lang['btn_download']          = 'הורדה';
$lang['btn_enable']            = 'שמירה';
$lang['url']                   = 'URL';
$lang['installed']             = 'מותקנות:';
$lang['lastupdate']            = 'עודכנו לאחרונה:';
$lang['source']                = 'מקור:';
$lang['unknown']               = 'לא ידוע';
$lang['updating']              = 'מעדכן ...';
$lang['updated']               = 'ההרחבה %s עודכנה בהצלחה';
$lang['updates']               = 'ההרחבות הבאות עודכנו בהצלחה';
$lang['update_none']           = 'לא נמצאו עידכונים.';
$lang['deleting']              = 'מוחק ...';
$lang['deleted']               = 'ההרחבה %s נמחקה.';
$lang['downloading']           = 'מוריד ...';
$lang['downloaded']            = 'ההרחבה %s הותקנה בהצלחה';
$lang['downloads']             = 'ההרחבות הבאות הותקנו בהצלחה:';
$lang['download_none']         = 'לא נמצאו הרחבות או שחלה בעיה בלתי ידועה במהלך ההורדה וההתקנה.';
$lang['plugin']                = 'הרחבה:';
$lang['components']            = 'רכיבים';
$lang['noinfo']                = 'הרחבה זו לא השיבה מידע, יתכן כי היא אינה בתוקף.';
$lang['name']                  = 'שם:';
$lang['date']                  = 'תאריך:';
$lang['type']                  = 'סוג:';
$lang['desc']                  = 'תיאור:';
$lang['author']                = 'מחבר:';
$lang['www']                   = 'רשת:';
$lang['error']                 = 'שגיאה לא ידועה ארעה.';
$lang['error_download']        = 'כשל בהורדת קובץ ההרחבה: %s';
$lang['error_badurl']          = 'כנראה כתובת שגויה - כשל בקביעת שם הקובץ מהכתובת';
$lang['error_dircreate']       = 'כשל ביצירת תיקיה זמנית לקבלת ההורדה';
$lang['error_decompress']      = 'מנהל ההרחבות כשל בפרישת הקובץ שהורד. יתכן כי זו תוצאה של הורדה תקולה ובמקרה זה עליך לנסות שנית; או שיתכן כי תסדיר הכיווץ אינו ידוע, במקרה זה יהיה עליך להוריד ולהתקין את ההרחבה ידנית.';
$lang['error_copy']            = 'חלה שגיאה בהעתקת הקובץ בניסיון להתקין קבצים להרחבה <em>%s</em>: ייתכן כי הדיסק מלא או שהרשאות הגישה לקבצים שגויות. יתכן כי בשל כך נוצרה התקנה חלקית של ההרחבה שתשאיר את התקנת הויקי שלך לא יציבה.';
$lang['error_delete']          = 'חלה שגיאה בעת ניסיון למחיקת ההרחבה <em>%s</em>.  הסיבה הסבירה ביותר היא הרשאות גישה לקבצים ולספריות שאינן מספקות';
$lang['enabled']               = 'תוסף %s מופעל.';
$lang['notenabled']            = 'לא ניתן להפעיל את התוסף %s, בדוק הרשאות קבצים.';
$lang['disabled']              = 'תוסף %s מושבת.';
$lang['notdisabled']           = 'לא ניתן להשבית את התוסף %s, בדוק הרשאות קבצים.';
